@@ -2,6 +2,8 @@
  *
  * Copyright (C) 2008 - 2014 Julian Andres Klode <jak@jak-linux.org>
  *
+ * SPDX-License-Identifier: MIT
+ *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
  * in the Software without restriction, including without limitation the rights
@@ -86,7 +88,7 @@ typedef enum hl_bool {
 #endif
 
 #ifdef HAVE_XATTR
-#include <attr/xattr.h>         /* listxattr, getxattr */
+#include <sys/xattr.h>          /* listxattr, getxattr */
 #endif
 
 /**
@@ -463,7 +465,7 @@ static int cmp_xattr_name_ptrs(const void *ptr1, const void *ptr2)
 
 /**
  * get_sorted_xattr_name_table - Create a sorted table of xattr names.
- * @names - table of concatentated, null-terminated xattr names
+ * @names - table of concatenated, null-terminated xattr names
  * @n - the number of names
  *
  * @Returns allocated table of pointers to the names, sorted alphabetically
@@ -1154,7 +1156,7 @@ static void to_be_called_atexit(void)
 }
 
 /**
- * sighandler - Signal hander, sets the global last_signal variable
+ * sighandler - Signal handler, sets the global last_signal variable
  * @i: The signal number
  */
 static void sighandler(int i)
